:github_url: https://github.com/j-bac/elpigraph-python/tree/master/elpigraph-python/elpigraph/utils.py#L11-L45



elpigraph.utils.getProjection
=============================

.. currentmodule:: elpigraph.utils

.. autofunction:: getProjection